@@ -7,6 +7,8 @@
 #include	"bifont.h"
 #include	"jsub.h"
 #ifdef KPATHSEA
+#undef STREQ
+#include	<kpathsea/config.h>
 #include	<kpathsea/tex-file.h>
 #endif
 
