@@ -2,7 +2,7 @@ enum cscom {
     callothersubr,
     callsubr,
     closepath,
-    div,
+    csdiv,
     dotsection,
     endchar,
     escape,
