@@ -1,8 +1,12 @@
+#include	"dvi2ps-conf.h"
+
 #include	"defs.h"
 #include	"commands.h"
 #include	"dconv.h"
 #include	"global.h"
 #ifdef KPATHSEA
+#undef STREQ
+#include	<kpathsea/config.h>
 #include	<kpathsea/progname.h>
 #include	<kpathsea/variable.h>
 #include	<kpathsea/proginit.h>
