@@ -169,7 +169,7 @@ char *newf, *newlcd, *ld, *lcd, *f, *ext;
 	} else
 	    return FALSE;
     }
-    if ((p = rindex(newlcd, '/')) != NULL)
+    if ((p = strrchr(newlcd, '/')) != NULL)
 	*(p+1) = '\0';
     else
 	*newlcd = '\0';
@@ -229,7 +229,7 @@ char *ext;
 	       || (isalpha(*f) && *(f+1) == ':')
 #endif
 	       ) {
-	p = rindex(f, '/');
+	p = strrchr(f, '/');
 #if defined(MSDOS) || defined(WIN32)
 	if (p == NULL)
 	    p = f+1;
@@ -241,7 +241,7 @@ char *ext;
     } else if (top) {
 	nld->defpath = dvi2lib;
 	if (strncmp(f, "./", 2) == 0 || strncmp(f, "../", 3) == 0) {
-	    p = rindex(f, '/');
+	    p = strrchr(f, '/');
 	    (void)strncpy(nld->dir, f, p+1-f);
 	    nld->dir[p+1-f] = '\0';
 	    return findsearchfile(newf, nld->lcldir, nld->dir, "", p+1, ext);
@@ -1188,7 +1188,7 @@ struct accarg *acca;
 	    case 's':
 #ifdef MSDOS
 		len = strlen(t = acca->pv_name);
-		if ((l = rindex(t, '.')) == NULL)
+		if ((l = strrchr(t, '.')) == NULL)
 		    l = t+len;
 		if (l-t > 8) {
 		    if (G_longfontname) {
