@@ -9,6 +9,8 @@
 #include	"rastfont.h"
 #include	"pkfont.h"
 #ifdef KPATHSEA
+#undef STREQ
+#include	<kpathsea/config.h>
 #include	<kpathsea/tex-file.h>
 #endif
 
