@@ -7,6 +7,8 @@
 #include	"global.h"
 #include	"ps.h"
 #ifdef KPATHSEA
+#undef STREQ
+#include	<kpathsea/config.h>
 #include	<kpathsea/tex-file.h>
 #endif
 
