@@ -182,6 +182,21 @@ int n;
 	}
 	return;
     }
+    if (strncmp(p, "src:", 4) == 0) {
+	return;
+    }
+    if (strncmp(p, "pos:", 4) == 0) {
+	return;
+    }
+    if (strncmp(p, "om:", 3) == 0) {
+	return;
+    }
+    if (strncmp(p, "xtex:", 5) == 0) {
+	return;
+    }
+    if (strncmp(p, "html:", 5) == 0) {
+	return;
+    }
 
     while ((p=GetKeyStr(p,&k)) != NULL) {	/* get all keyword-value pairs */
 	/* for compatibility, single words are taken as file names */
@@ -434,6 +449,21 @@ int n;
 	EMITS("@endspecial\n");
 	return;
     }
+    if (strncmp(p, "src:", 4) == 0) {
+	return;
+    }
+    if (strncmp(p, "pos:", 4) == 0) {
+	return;
+    }
+    if (strncmp(p, "om:", 3) == 0) {
+	return;
+    }
+    if (strncmp(p, "xtex:", 5) == 0) {
+	return;
+    }
+    if (strncmp(p, "html:", 5) == 0) {
+	return;
+    }
 
     EMIT(outfp, "@beginspecial\n");
     while ((p=GetKeyStr(p,&k)) != NULL) {	/* get all keyword-value pairs */
