@@ -41,7 +41,7 @@ int firstch;
 {
     char s[STRLEN];
     char *sp;
-    int c, len;
+    int c, len, w;
     DEV_FONT devf;
 
     /* read entire string of chars */
@@ -61,7 +61,8 @@ int firstch;
 	chmove = TRUE;
 	dev_setfont(devf);
 	dev_setposn(h, v);
-	*move += DEV_setstring(s, len);
+	w = DEV_setstring(s, len);
+	*move += w;
     } else
 	dev_setposn(h, v);
 
