@@ -169,6 +169,11 @@ char *fontdescfile;
 			Fatal("Argument is not a valid integer\n");
 		    break;
 
+		case 'v':	/* print version */
+		    (void)fprintf(stderr, "%s\n", version);
+		    AbortRun(0);
+		    break;
+
 		case 'w':	/* don't print out warnings */
 		    ChangeFlag(G_nowarn);
 		    break;
@@ -182,7 +187,7 @@ char *fontdescfile;
 
     /* dvifilename, dvidirpath, dvifp are set */
     if (argind < argc) {
-	tcp = rindex(argv[argind], DIR_SEP);	/* split into directory + file name */
+	tcp = strrchr(argv[argind], DIR_SEP);	/* split into directory + file name */
 	if (tcp == NULL)  {
 	    dvidirpath[0] = '\0';
 	    tcp = argv[argind];
@@ -197,7 +202,7 @@ char *fontdescfile;
 	if (strlen(tcp)+4+1 >= PATHLEN)
 	    Fatal("DVI file name \"%s\" too long", tcp);
 	(void)strcpy(curname, tcp);
-	tcp1 = rindex(tcp, '.');	/* split into file name + extension */
+	tcp1 = strrchr(tcp, '.');	/* split into file name + extension */
 	if (tcp1 == NULL)
 	    (void)strcat(curname, ".dvi");
 	else
@@ -317,7 +322,7 @@ char c;
 		  "[-R resolution] [-S]",
 		  "[-c psfile] [-d] [-f n] [-i file]",
 		  "[-m{0|h|1|2|3|4|5}] [-m mag] [-n n]",
-		  "[-o option] [-q] [-r] [-s file] [-t n] [-w]",
+		  "[-o option] [-q] [-r] [-s file] [-t n] [-v] [-w]",
 		  "[dvifile]");
     (void)fprintf(stderr, "%s\n", version);
     AbortRun(2);
