@@ -20,6 +20,11 @@
  * version 3.2j  (Jan 2001)
  * version 4.0j  (Feb 2004)
  * version 4.1j  (Aug 2006)
+ * version 4.2j  (Aug 2010)
+ * version 5.0j  (Dec 2010)
+ * version 5.1j  (Aug 2011)
  */
 
-char *version = "@(#)dvi2ps (j-version) 4.1j";
+#include	"conf.h"
+
+char *version = "@(#)dvi2ps (j-version) "PACKAGE_VERSION;
