@@ -128,7 +128,7 @@ BOOLEAN settfmw;
 		continue;
 	    if (settfmw)
 		(vflfi->ch+i)->tfmw = tfmw;
-	    bzero(pixel, size);
+	    memset(pixel, 0, size);
 	    c = idx94_to_std(i);
 	    VF_GetBitmap(c, fid, width, height, bwid, 0, pixel);
 	    trim_bitmap(width, bwid, height, 0, depth, pixel,
