@@ -33,7 +33,7 @@ int firstch;
 {
     char s[STRLEN];
     char *sp;
-    int c, len;
+    int c, len, w;
 
     /* read entire string of chars */
     /* ensure that all characters are loaded, */
@@ -45,7 +45,8 @@ int firstch;
     DC_backupone();
 
     chmove = TRUE;
-    *move += DEV_setstring(s, len);
+    w = DEV_setstring(s, len);
+    *move += w;
 
 #ifdef STATS
     Stnc += len;
