@@ -8,6 +8,8 @@
 #include	"global.h"
 #include	"virfont.h"
 #ifdef KPATHSEA
+#undef STREQ
+#include	<kpathsea/config.h>
 #include	<kpathsea/tex-file.h>
 #endif
 
@@ -41,7 +43,8 @@ char *proto;
 struct font_entry *fe;
 struct accarg *acca;
 {
-    return vfty_acc(proto, fe, acca, "jvf", ".jvf");
+    /*return vfty_acc(proto, fe, acca, "jvf", ".jvf");*/
+    return vfty_acc(proto, fe, acca, "jvf", NULL);
 }
 
 vfty_acc(proto, fe, acca, type, suffix)
@@ -517,10 +520,13 @@ unsigned char *s;
 int len;
 {
     unsigned char *sp;
+    int w;
 
     /* should be optimized */
-    for (sp = s; sp < s+len; sp++)
-	*move += vf_setchar(*sp);
+    for (sp = s; sp < s+len; sp++) {
+	w = vf_setchar(*sp);
+	*move += w;
+    }
     return 0;
 }
 
@@ -529,9 +535,12 @@ unsigned char *s;
 int len;
 {
     unsigned char *sp;
+    int w;
 
     /* should be optimized */
-    for (sp = s; sp < s+len; sp++)
-	*move += jvf_setchar(*sp);
+    for (sp = s; sp < s+len; sp++) {
+	w = jvf_setchar(*sp);
+	*move += w;
+    }
     return 0;
 }
